@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 import rest
 import platform
 import cups
@@ -262,8 +262,8 @@ class App(object):
         self.printers = printers
         self.pidfile_path = pidfile_path
         self.stdin_path = '/dev/null'
-        self.stdout_path = '/dev/tty'
-        self.stderr_path = '/dev/tty'
+        self.stdout_path = '/dev/null'
+        self.stderr_path = '/dev/null'
         self.pidfile_timeout = 5
 
     def run(self):
